==> jc-1.4.0.tar.gz: gnu/java/lang/reflect/TypeSignature.h <==
// public class gnu.java.lang.reflect.TypeSignature

// class file dependencies
// @dep_class 9153b7e32d9ef497 gnu_java_lang_reflect_TypeSignature
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_lang_reflect_TypeSignature_H_
#define _JC_gnu_java_lang_reflect_TypeSignature_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Constructor$object;
struct _jc_java_lang_reflect_Member$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_gnu_java_lang_reflect_TypeSignature$sub_refs	_jc_gnu_java_lang_reflect_TypeSignature$sub_refs;
typedef struct _jc_gnu_java_lang_reflect_TypeSignature$sub_nonrefs	_jc_gnu_java_lang_reflect_TypeSignature$sub_nonrefs;
typedef struct _jc_gnu_java_lang_reflect_TypeSignature$refs	_jc_gnu_java_lang_reflect_TypeSignature$refs;
typedef struct _jc_gnu_java_lang_reflect_TypeSignature$nonrefs	_jc_gnu_java_lang_reflect_TypeSignature$nonrefs;
typedef struct _jc_gnu_java_lang_reflect_TypeSignature$object	_jc_gnu_java_lang_reflect_TypeSignature$object;

typedef const struct _jc_gnu_java_lang_reflect_TypeSignature$vmethods	_jc_gnu_java_lang_reflect_TypeSignature$vmethods;
typedef const struct _jc_gnu_java_lang_reflect_TypeSignature$vtable	_jc_gnu_java_lang_reflect_TypeSignature$vtable;
typedef const struct _jc_gnu_java_lang_reflect_TypeSignature$vtype	_jc_gnu_java_lang_reflect_TypeSignature$vtype;

// Constructors
extern void _jc_gnu_java_lang_reflect_TypeSignature$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_lang_reflect_TypeSignature$object *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getClassForEncoding$2a32c8a573eb7415(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getClassForEncoding$5427652101b3b57e(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getClassForEncoding$367413afee32d61a(_jc_env *, struct _jc_java_lang_String$object *, jboolean, struct _jc_java_lang_ClassLoader$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfClass$89001cf3b6393d5b(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfClass$dc86d8587e5f6686(_jc_env *, struct _jc_java_lang_Class$object *, jboolean);
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfClass$6fb66527bfa6059a(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfConstructor$aa83321f1a8a7411(_jc_env *, struct _jc_java_lang_reflect_Constructor$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfMember$c8b39cc1b2462081(_jc_env *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfMethod$bf26551b8415c85a(_jc_env *, struct _jc_java_lang_reflect_Method$object *);

// Virtual methods structure
struct _jc_gnu_java_lang_reflect_TypeSignature$vmethods {
};

// Vtable
struct _jc_gnu_java_lang_reflect_TypeSignature$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_lang_reflect_TypeSignature$vmethods	gnu_java_lang_reflect_TypeSignature;
};

// Vtype
struct _jc_gnu_java_lang_reflect_TypeSignature$vtype {
	_jc_type			type;
	_jc_gnu_java_lang_reflect_TypeSignature$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_lang_reflect_TypeSignature$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_lang_reflect_TypeSignature$refs {
    _jc_gnu_java_lang_reflect_TypeSignature$sub_refs	gnu_java_lang_reflect_TypeSignature;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_lang_reflect_TypeSignature$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_lang_reflect_TypeSignature$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_lang_reflect_TypeSignature$sub_nonrefs	gnu_java_lang_reflect_TypeSignature;
};

// Object instance structure
struct _jc_gnu_java_lang_reflect_TypeSignature$object {
	_jc_gnu_java_lang_reflect_TypeSignature$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_lang_reflect_TypeSignature$vtype	*vtype;
	_jc_gnu_java_lang_reflect_TypeSignature$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_lang_reflect_TypeSignature$vtype _jc_gnu_java_lang_reflect_TypeSignature$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_lang_reflect_TypeSignature, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_lang_reflect_TypeSignature$class_object;

#endif	/* _JC_gnu_java_lang_reflect_TypeSignature_H_ */

==> jc-1.4.6.tar.gz: gnu/java/lang/reflect/TypeSignature.h <==
// public class gnu.java.lang.reflect.TypeSignature

// class file dependencies
// @dep_class 9153b7e32d9ef497 gnu_java_lang_reflect_TypeSignature
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_lang_reflect_TypeSignature_H_
#define _JC_gnu_java_lang_reflect_TypeSignature_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Constructor$object;
struct _jc_java_lang_reflect_Member$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_gnu_java_lang_reflect_TypeSignature$sub_refs	_jc_gnu_java_lang_reflect_TypeSignature$sub_refs;
typedef struct _jc_gnu_java_lang_reflect_TypeSignature$sub_nonrefs	_jc_gnu_java_lang_reflect_TypeSignature$sub_nonrefs;
typedef struct _jc_gnu_java_lang_reflect_TypeSignature$refs	_jc_gnu_java_lang_reflect_TypeSignature$refs;
typedef struct _jc_gnu_java_lang_reflect_TypeSignature$nonrefs	_jc_gnu_java_lang_reflect_TypeSignature$nonrefs;
typedef struct _jc_gnu_java_lang_reflect_TypeSignature$object	_jc_gnu_java_lang_reflect_TypeSignature$object;

typedef const struct _jc_gnu_java_lang_reflect_TypeSignature$vmethods	_jc_gnu_java_lang_reflect_TypeSignature$vmethods;
typedef const struct _jc_gnu_java_lang_reflect_TypeSignature$vtable	_jc_gnu_java_lang_reflect_TypeSignature$vtable;
typedef const struct _jc_gnu_java_lang_reflect_TypeSignature$vtype	_jc_gnu_java_lang_reflect_TypeSignature$vtype;

// Constructors
extern void _jc_gnu_java_lang_reflect_TypeSignature$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_lang_reflect_TypeSignature$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getClassForEncoding$2a32c8a573eb7415(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getClassForEncoding$5427652101b3b57e(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getClassForEncoding$367413afee32d61a(_jc_env *, struct _jc_java_lang_String$object *, jboolean, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfClass$89001cf3b6393d5b(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfClass$dc86d8587e5f6686(_jc_env *, struct _jc_java_lang_Class$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfClass$6fb66527bfa6059a(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfConstructor$aa83321f1a8a7411(_jc_env *, struct _jc_java_lang_reflect_Constructor$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfMember$c8b39cc1b2462081(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_lang_reflect_TypeSignature$method$getEncodingOfMethod$bf26551b8415c85a(_jc_env *, struct _jc_java_lang_reflect_Method$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_lang_reflect_TypeSignature$vmethods {
};

// Vtable
struct _jc_gnu_java_lang_reflect_TypeSignature$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_lang_reflect_TypeSignature$vmethods	gnu_java_lang_reflect_TypeSignature;
};

// Vtype
struct _jc_gnu_java_lang_reflect_TypeSignature$vtype {
	_jc_type			type;
	_jc_gnu_java_lang_reflect_TypeSignature$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_lang_reflect_TypeSignature$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_lang_reflect_TypeSignature$refs {
    _jc_gnu_java_lang_reflect_TypeSignature$sub_refs	gnu_java_lang_reflect_TypeSignature;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_lang_reflect_TypeSignature$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_lang_reflect_TypeSignature$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_lang_reflect_TypeSignature$sub_nonrefs	gnu_java_lang_reflect_TypeSignature;
};

// Object instance structure
struct _jc_gnu_java_lang_reflect_TypeSignature$object {
	_jc_gnu_java_lang_reflect_TypeSignature$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_lang_reflect_TypeSignature$vtype	*vtype;
	_jc_gnu_java_lang_reflect_TypeSignature$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_lang_reflect_TypeSignature$vtype _jc_gnu_java_lang_reflect_TypeSignature$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_lang_reflect_TypeSignature, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_lang_reflect_TypeSignature$class_object;

#endif	/* _JC_gnu_java_lang_reflect_TypeSignature_H_ */
